@@ -2,11 +2,11 @@
 ===============================================================================
 
   FILE:  lasreader_dtm.cpp
-
+  
   CONTENTS:
-
+  
     see corresponding header file
-
+  
   PROGRAMMERS:
 
     martin.isenburg@rapidlasso.com  -  http://rapidlasso.com
@@ -21,17 +21,14 @@
 
     This software is distributed WITHOUT ANY WARRANTY and without even the
     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
+  
   CHANGE HISTORY:
-
-    20 December 2016 -- by Jean-Romain Roussel -- Change fprint(stderr, ...), raise an exeption
-
+  
     see corresponding header file
-
+  
 ===============================================================================
 */
 #include "lasreader_dtm.hpp"
-#include <stdexcept>
 
 // used to map GeoTIFF codes to GCTP codes
 
@@ -292,7 +289,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
 {
   if (file_name == 0)
   {
-    throw std::runtime_error(std::string("ERROR: fine name pointer is zero"));
+    REprintf("ERROR: file name pointer is zero\n");
     return FALSE;
   }
 
@@ -305,13 +302,13 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   file = fopen(file_name, "rb");
   if (file == 0)
   {
-    throw std::runtime_error(std::string("ERROR: cannot open file '%s'")); //file_name
+    REprintf( "ERROR: cannot open file '%s'\n", file_name);
     return FALSE;
   }
 
   if (setvbuf(file, NULL, _IOFBF, 2*LAS_TOOLS_IO_IBUFFER_SIZE) != 0)
   {
-    throw std::runtime_error(std::string("WARNING: setvbuf() failed with buffer size %d")); //2*LAS_TOOLS_IO_IBUFFER_SIZE
+    REprintf( "WARNING: setvbuf() failed with buffer size %d\n", 2*LAS_TOOLS_IO_IBUFFER_SIZE);
   }
 
   // read the 200 byte header
@@ -319,7 +316,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   CHAR signature[21];
   if (fread(signature, 1, 21, file) != 21)
   {
-    throw std::runtime_error(std::string("ERROR: reading 21 byte signature for '%s'")); //file_name
+    REprintf( "ERROR: reading 21 byte signature for '%s'\n", file_name);
     return FALSE;
   }
 
@@ -327,7 +324,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
 
   if (strncmp(signature, "PLANS-PC BINARY .DTM", 21) != 0)
   {
-    throw std::runtime_error(std::string("ERROR: cannot open DTM file '%s', wrong signature '%21s'")); //file_name, signature
+    REprintf( "ERROR: cannot open DTM file '%s', wrong signature '%21s'\n", file_name, signature);
     return FALSE;
   }
 
@@ -336,7 +333,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   CHAR description[61];
   if (fread(description, 1, 61, file) != 61)
   {
-    throw std::runtime_error(std::string("ERROR: reading 61 byte description for '%s'")); //file_name
+    REprintf( "ERROR: reading 61 byte description for '%s'\n", file_name);
     return FALSE;
   }
 
@@ -345,7 +342,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   F32 version;
   if (fread(&version, 4, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 4 byte version for '%s'")); //file_name
+    REprintf( "ERROR: reading 4 byte version for '%s'\n", file_name);
     return FALSE;
   }
 
@@ -353,7 +350,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
 
   if (version != 3.1f)
   {
-    throw std::runtime_error(std::string("WARNING: expected 3.1 but version is %1.1f")); //version
+    REprintf( "WARNING: expected 3.1 but version is %1.1f\n", version);
   }
 
   // read lower left x
@@ -368,7 +365,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   {
   }
 
-  // read min_z
+  // read min_z 
 
   F64 min_z;
   if (fread(&min_z, 8, 1, file) != 1)
@@ -393,7 +390,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
 
   if (rotation != 0.0)
   {
-    throw std::runtime_error(std::string("WARNING: expected 0.0 but rotation is %g")); //rotation
+    REprintf( "WARNING: expected 0.0 but rotation is %g\n", rotation);
   }
 
   F64 column_spacing;
@@ -411,7 +408,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   if (fread(&ncols, 4, 1, file) != 1)
   {
   }
-
+  
   if (fread(&nrows, 4, 1, file) != 1)
   {
   }
@@ -429,43 +426,43 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
 
   if (fread(&horizontal_units, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte horizontal_units for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte horizontal_units for '%s'\n", file_name);
     return FALSE;
   }
 
   if (fread(&vertical_units, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte vertical_units for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte vertical_units for '%s'\n", file_name);
     return FALSE;
   }
 
   if (fread(&data_type, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte data_type for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte data_type for '%s'\n", file_name);
     return FALSE;
   }
 
   if (fread(&coordinate_system, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte horizontal_units for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte horizontal_units for '%s'\n", file_name);
     return FALSE;
   }
 
   if (fread(&coordinate_zone, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte coordinate_zone for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte coordinate_zone for '%s'\n", file_name);
     return FALSE;
   }
 
   if (fread(&horizontal_datum, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte horizontal_datum for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte horizontal_datum for '%s'\n", file_name);
     return FALSE;
   }
 
   if (fread(&vertical_datum, 2, 1, file) != 1)
   {
-    throw std::runtime_error(std::string("ERROR: reading 2 byte vertical_datum for '%s'")); //file_name
+    REprintf( "ERROR: reading 2 byte vertical_datum for '%s'\n", file_name);
     return FALSE;
   }
 
@@ -484,7 +481,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
       }
       else
       {
-        throw std::runtime_error(std::string("UTM zone %d for NAD27 out-of-range")); //(int)coordinate_zone
+        REprintf( "UTM zone %d for NAD27 out-of-range\n", (int)coordinate_zone);
       }
     }
     else if (horizontal_datum == 2) // GEO_DATUM_NAD83
@@ -499,7 +496,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
       }
       else
       {
-        throw std::runtime_error(std::string("UTM zone %d for NAD83 out-of-range")); //(int)coordinate_zone
+        REprintf( "UTM zone %d for NAD83 out-of-range\n", (int)coordinate_zone);
       }
     }
     else if (horizontal_datum == 3) // GEO_DATUM_WGS84
@@ -905,7 +902,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
         geokey = PCS_NAD83_Puerto_Rico;
         break;
       default:
-        throw std::runtime_error(std::string("state plane NAD83 zone %d not implemented")); //(int)coordinate_zone
+        REprintf( "state plane NAD83 zone %d not implemented\n", (int)coordinate_zone);
       }
     }
 
@@ -946,7 +943,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
     geo_keys[num_geo_keys].value_offset = (vertical_units == 1 ? 9001 : 9002);
     num_geo_keys++;
   }
-
+  
   if (vertical_datum)
   {
     // vertical datum
@@ -967,7 +964,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
     }
     num_geo_keys++;
   }
-
+      
   if (num_geo_keys)
   {
     header.set_geo_keys(num_geo_keys, geo_keys);
@@ -985,14 +982,14 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
 
   if (xdim <= 0)
   {
-    throw std::runtime_error(std::string("WARNING: xdim was %g. setting to 1.0")); //xdim
+    REprintf("WARNING: xdim was %g. setting to 1.0\n", xdim);
     xdim = 1;
   }
 
   if (ydim <= 0)
   {
     ydim = 1;
-    throw std::runtime_error(std::string("WARNING: ydim was %g. setting to 1.0")); //ydim
+    REprintf("WARNING: ydim was %g. setting to 1.0\n", ydim);
   }
 
   // populate the header as much as it makes sense
@@ -1137,7 +1134,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   }
   else
   {
-    throw std::runtime_error(std::string("ERROR: unknown data type %d")); //(I32)data_type
+    REprintf("ERROR: unknown data type %d\n", (I32)data_type);
     return FALSE;
   }
 
@@ -1157,7 +1154,7 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
   }
   else
   {
-    throw std::runtime_error(std::string("WARNING: DTM raster contains only no data values"));
+    REprintf("WARNING: DTM raster contains only no data values\n");
     header.min_z = 0;
     header.max_z = 0;
   }
@@ -1221,9 +1218,9 @@ BOOL LASreaderDTM::read_point_default()
       if (fread((void*)&elevation, 4, 1, file) != 1)
       {
 #ifdef _WIN32
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
         npoints = p_count;
         return FALSE;
@@ -1235,9 +1232,9 @@ BOOL LASreaderDTM::read_point_default()
       if (fread((void*)&elev, 4, 1, file) != 1)
       {
 #ifdef _WIN32
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
         npoints = p_count;
         return FALSE;
@@ -1250,9 +1247,9 @@ BOOL LASreaderDTM::read_point_default()
       if (fread((void*)&elev, 2, 1, file) != 1)
       {
 #ifdef _WIN32
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
         npoints = p_count;
         return FALSE;
@@ -1265,9 +1262,9 @@ BOOL LASreaderDTM::read_point_default()
       if (fread((void*)&elev, 8, 1, file) != 1)
       {
 #ifdef _WIN32
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
         npoints = p_count;
         return FALSE;
@@ -1276,7 +1273,7 @@ BOOL LASreaderDTM::read_point_default()
     }
     else
     {
-      throw std::runtime_error(std::string("ERROR: unknown data type %d")); //(I32)data_type
+      REprintf("ERROR: unknown data type %d\n", (I32)data_type);
       return FALSE;
     }
 
@@ -1315,7 +1312,7 @@ BOOL LASreaderDTM::reopen(const CHAR* file_name)
 {
   if (file_name == 0)
   {
-    throw std::runtime_error(std::string("ERROR: fine name pointer is zero"));
+    REprintf("ERROR: file name pointer is zero\n");
     return FALSE;
   }
 
@@ -1330,13 +1327,13 @@ BOOL LASreaderDTM::reopen(const CHAR* file_name)
   file = fopen(file_name, "rb");
   if (file == 0)
   {
-    throw std::runtime_error(std::string("ERROR: cannot reopen file '%s'")); //file_name
+    REprintf( "ERROR: cannot reopen file '%s'\n", file_name);
     return FALSE;
   }
 
   if (setvbuf(file, NULL, _IOFBF, 2*LAS_TOOLS_IO_IBUFFER_SIZE) != 0)
   {
-    throw std::runtime_error(std::string("WARNING: setvbuf() failed with buffer size %d")); //2*LAS_TOOLS_IO_IBUFFER_SIZE
+    REprintf( "WARNING: setvbuf() failed with buffer size %d\n", 2*LAS_TOOLS_IO_IBUFFER_SIZE);
   }
 
   col = 0;
@@ -1461,8 +1458,8 @@ void LASreaderDTM::populate_bounding_box()
 
   if ((header.min_x > 0) != (dequant_min_x > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for min_x from %g to %g.")); //header.min_x, dequant_min_x
-    throw std::runtime_error(std::string("         set scale factor for x coarser than %g with '-rescale'")); //header.x_scale_factor
+    REprintf( "WARNING: quantization sign flip for min_x from %g to %g.\n", header.min_x, dequant_min_x);
+    REprintf( "         set scale factor for x coarser than %g with '-rescale'\n", header.x_scale_factor);
   }
   else
   {
@@ -1470,8 +1467,8 @@ void LASreaderDTM::populate_bounding_box()
   }
   if ((header.max_x > 0) != (dequant_max_x > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for max_x from %g to %g.")); //header.max_x, dequant_max_x
-    throw std::runtime_error(std::string("         set scale factor for x coarser than %g with '-rescale'")); //header.x_scale_factor
+    REprintf( "WARNING: quantization sign flip for max_x from %g to %g.\n", header.max_x, dequant_max_x);
+    REprintf( "         set scale factor for x coarser than %g with '-rescale'\n", header.x_scale_factor);
   }
   else
   {
@@ -1479,8 +1476,8 @@ void LASreaderDTM::populate_bounding_box()
   }
   if ((header.min_y > 0) != (dequant_min_y > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for min_y from %g to %g.")); //header.min_y, dequant_min_y
-    throw std::runtime_error(std::string("         set scale factor for y coarser than %g with '-rescale'")); //header.y_scale_factor
+    REprintf( "WARNING: quantization sign flip for min_y from %g to %g.\n", header.min_y, dequant_min_y);
+    REprintf( "         set scale factor for y coarser than %g with '-rescale'\n", header.y_scale_factor);
   }
   else
   {
@@ -1488,8 +1485,8 @@ void LASreaderDTM::populate_bounding_box()
   }
   if ((header.max_y > 0) != (dequant_max_y > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for max_y from %g to %g.")); //header.max_y, dequant_max_y
-    throw std::runtime_error(std::string("         set scale factor for y coarser than %g with '-rescale'")); //header.y_scale_factor
+    REprintf( "WARNING: quantization sign flip for max_y from %g to %g.\n", header.max_y, dequant_max_y);
+    REprintf( "         set scale factor for y coarser than %g with '-rescale'\n", header.y_scale_factor);
   }
   else
   {
@@ -1497,8 +1494,8 @@ void LASreaderDTM::populate_bounding_box()
   }
   if ((header.min_z > 0) != (dequant_min_z > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for min_z from %g to %g.")); //header.min_z, dequant_min_z
-    throw std::runtime_error(std::string("         set scale factor for z coarser than %g with '-rescale'")); //header.z_scale_factor
+    REprintf( "WARNING: quantization sign flip for min_z from %g to %g.\n", header.min_z, dequant_min_z);
+    REprintf( "         set scale factor for z coarser than %g with '-rescale'\n", header.z_scale_factor);
   }
   else
   {
@@ -1506,8 +1503,8 @@ void LASreaderDTM::populate_bounding_box()
   }
   if ((header.max_z > 0) != (dequant_max_z > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for max_z from %g to %g.")); //header.max_z, dequant_max_z
-    throw std::runtime_error(std::string("         set scale factor for z coarser than %g with '-rescale'")); //header.z_scale_factor
+    REprintf( "WARNING: quantization sign flip for max_z from %g to %g.\n", header.max_z, dequant_max_z);
+    REprintf( "         set scale factor for z coarser than %g with '-rescale'\n", header.z_scale_factor);
   }
   else
   {
