@@ -2,17 +2,17 @@
 ===============================================================================
 
   FILE:  lasinterval.cpp
-  
+
   CONTENTS:
-  
+
     see corresponding header file
-  
+
   PROGRAMMERS:
-  
+
     martin.isenburg@rapidlasso.com  -  http://rapidlasso.com
-  
+
   COPYRIGHT:
-  
+
     (c) 2011-2015, martin isenburg, rapidlasso - fast tools to catch reality
 
     This is free software; you can redistribute and/or modify it under the
@@ -21,14 +21,15 @@
 
     This software is distributed WITHOUT ANY WARRANTY and without even the
     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-  
+
   CHANGE HISTORY:
-  
+
     see corresponding header file
-  
+
 ===============================================================================
 */
 #include "lasinterval.hpp"
+#include "laszip.hpp"
 
 #include "bytestreamin.hpp"
 #include "bytestreamout.hpp"
@@ -43,7 +44,7 @@
 using namespace std;
 
 #ifdef UNORDERED
-   // Figure out whether <unordered_map> is in tr1
+// Figure out whether <unordered_map> is in tr1
 #  ifdef __has_include
 #    if __has_include(<unordered_map>)
 #     include <unordered_map>
@@ -52,7 +53,7 @@ using namespace std;
 #    endif
 #  endif
 #  ifndef UNORDERED_FOUND
-#    include <tr1/unordered_map>
+#   include <tr1/unordered_map>
     using namespace std;
     using namespace tr1;
 #   endif
@@ -160,7 +161,7 @@ BOOL LASinterval::add(const U32 p_index, const I32 c_index)
 // get total number of cells
 U32 LASinterval::get_number_cells() const
 {
-  return ((my_cell_hash*)cells)->size();
+  return (U32)((my_cell_hash*)cells)->size();
 }
 
 // get total number of intervals
@@ -231,17 +232,27 @@ void LASinterval::merge_intervals(U32 maximum_intervals, const BOOL verbose)
     hash_element++;
   }
 
-  my_cell_map::iterator map_element = map.begin();
-  diff = (*map_element).first;
-
   // maybe nothing to do
   if (map.size() <= maximum_intervals)
   {
-    if (verbose) REprintf("next largest interval gap is %u\n", diff);
+    if (verbose)
+    {
+      if (map.size() == 0)
+      {
+        REprintf("maximum_intervals: %u number of interval gaps: 0 \n", maximum_intervals);
+      }
+      else
+      {
+        diff = (*(map.begin())).first;
+        REprintf("maximum_intervals: %u number of interval gaps: %u next largest interval gap %u\n", maximum_intervals, (U32)map.size(), diff);
+      }
+    }
     return;
   }
 
-  U32 size = map.size();
+  my_cell_map::iterator map_element;
+  U32 size = (U32)map.size();
+
   while (size > maximum_intervals)
   {
     map_element = map.begin();
@@ -641,20 +652,20 @@ BOOL LASinterval::read(ByteStreamIn* stream)
 
 BOOL LASinterval::write(ByteStreamOut* stream) const
 {
-  if (!stream->putBytes((U8*)"LASV", 4))
+  if (!stream->putBytes((const U8*)"LASV", 4))
   {
     REprintf("ERROR (LASinterval): writing signature\n");
     return FALSE;
   }
   U32 version = 0;
-  if (!stream->put32bitsLE((U8*)&version))
+  if (!stream->put32bitsLE((const U8*)&version))
   {
     REprintf("ERROR (LASinterval): writing version\n");
     return FALSE;
   }
   // write number of cells
-  U32 number_cells = ((my_cell_hash*)cells)->size();
-  if (!stream->put32bitsLE((U8*)&number_cells))
+  U32 number_cells = (U32)((my_cell_hash*)cells)->size();
+  if (!stream->put32bitsLE((const U8*)&number_cells))
   {
     REprintf("ERROR (LASinterval): writing number of cells %d\n", number_cells);
     return FALSE;
@@ -674,19 +685,19 @@ BOOL LASinterval::write(ByteStreamOut* stream) const
     }
     // write index of cell
     I32 cell_index = (*hash_element).first;
-    if (!stream->put32bitsLE((U8*)&cell_index))
+    if (!stream->put32bitsLE((const U8*)&cell_index))
     {
       REprintf("ERROR (LASinterval): writing cell index %d\n", cell_index);
       return FALSE;
     }
     // write number of intervals in cell
-    if (!stream->put32bitsLE((U8*)&number_intervals))
+    if (!stream->put32bitsLE((const U8*)&number_intervals))
     {
       REprintf("ERROR (LASinterval): writing number of intervals %d in cell\n", number_intervals);
       return FALSE;
     }
     // write number of points in cell
-    if (!stream->put32bitsLE((U8*)&number_points))
+    if (!stream->put32bitsLE((const U8*)&number_points))
     {
       REprintf("ERROR (LASinterval): writing number of points %d in cell\n", number_points);
       return FALSE;
@@ -696,13 +707,13 @@ BOOL LASinterval::write(ByteStreamOut* stream) const
     while (cell)
     {
       // write start of interval
-      if (!stream->put32bitsLE((U8*)&(cell->start)))
+      if (!stream->put32bitsLE((const U8*)&(cell->start)))
       {
         REprintf("ERROR (LASinterval): writing start %d of interval\n", cell->start);
         return FALSE;
       }
       // write end of interval
-      if (!stream->put32bitsLE((U8*)&(cell->end)))
+      if (!stream->put32bitsLE((const U8*)&(cell->end)))
       {
         REprintf("ERROR (LASinterval): writing end %d of interval\n", cell->end);
         return FALSE;
