@@ -1,20 +1,6 @@
 #include <Rcpp.h>
 using namespace Rcpp;
 
-// [[Rcpp::export]]
-IntegerVector fast_table(IntegerVector x, int size = 5)
-{
-  IntegerVector tbl(size);
-
-  for (IntegerVector::iterator it = x.begin(), end = x.end() ; it != end ; ++it)
-  {
-    if (*it <= size && *it > 0)
-      tbl(*it-1)++;
-  }
-
-  return tbl;
-}
-
 // [[Rcpp::export]]
 int fast_countequal(IntegerVector x, int t)
 {
