@@ -35,6 +35,7 @@
 
 #include "lasreader.hpp"
 #include "lasfilter.hpp"
+#include "lastransform.hpp"
 
 
 using namespace Rcpp;
@@ -410,6 +411,20 @@ void lasfilterusage()
   }
 }
 
+// [[Rcpp::export]]
+void lastransformusage()
+{
+  try
+  {
+    LAStransform transform;
+    transform.usage();
+  }
+  catch (std::exception const& e)
+  {
+    Rcerr << "Error: " << e.what() << std::endl;
+  }
+}
+
 inline std::string nullterminate(CHAR* str, int len)
 {
   if (str[len-1] != '\0')
